#!/usr/bin/env python3

__author__ = 'jurgenhaas'

import subprocess

class Oracle:
    def __init__(self, agentConfig, checksLogger, rawConfig):
        self.agentConfig = agentConfig
        self.checksLogger = checksLogger
        self.rawConfig = rawConfig

    def run(self):
        system_names = {'SYSAUX': 1, 'SYSTEM': 2, 'UNDOTBS1': 3}
        out = subprocess.check_output('/usr/bin/sd-agent/plugins/Oracle.sh')
        r_allocated = 0
        r_used = 0
        r_percentage = 0
        r_allocated_userdata = 0
        r_used_userdata = 0
        r_percentage_userdata = 0
        r_percentage_max = 0
        try:
            for name, allocated, used, blocks, percentage, dummy in [line.split('|') for line in out.splitlines()]:
                print(name.strip() + ':')
                r_allocated += int(allocated)
                r_used += float(used)
                if name.strip() not in system_names:
                    print(' is userdata')
                    r_allocated_userdata += int(allocated)
                    r_used_userdata += float(used)
                percentage = float(percentage.rstrip('%'))
                if percentage > r_percentage_max:
                    r_percentage_max = percentage
        except Exception as e:
            pass

        if r_allocated > 0:
            r_percentage = r_used / r_allocated * 100

        if r_allocated_userdata > 0:
            r_percentage_userdata = r_used_userdata / r_allocated_userdata * 100

        result = {
            'allocated': str(r_allocated),
            'allocated_userdata': str(r_allocated_userdata),
            'used': str(r_used),
            'used_userdata': str(r_used_userdata),
            'percentage': str(r_percentage),
            'percentage_userdata': str(r_percentage_userdata),
            'percentage_max': str(r_percentage_max)
        }
        return result

if __name__ == '__main__':
    oracle = Oracle(None, None, None)
    print(oracle.run())
