#!/usr/bin/python3

RETURN = '''# '''

from subprocess import Popen, PIPE, STDOUT

def main():
    module = AnsibleModule(
        argument_spec=dict(
            mode=dict(required=False, default='check'),
            ignore=dict(required=False, default=False)
        ),
        supports_check_mode=False
    )
    if module.params['ignore']:
        module.exit_json(changed=False, result='Ignored')
    mode = module.params['mode']

    process = Popen(['which', 'ncu'], stdout=PIPE, stderr=STDOUT)
    process.wait()
    if process.stdout.read() == b'':
        module.exit_json(changed=False, result='Node/npm/ncu not available')

    process = Popen(['ncu', '-g'], stdout=PIPE, stderr=STDOUT)
    process.wait()
    updates = []
    for line in process.stdout.read().decode('utf8').split("\n"):
        if line == '':
            # Ignore empty lines
            pass
        elif line[0] == ' ':
            # This is for us
            updates.append(line.strip())
        else:
            # Ignore everything else
            pass

    if len(updates) == 0:
        module.exit_json(changed=False, result="No updates available")

    if mode == 'upgrade':
        output = []
        for update in updates:
            pkg = update.split(' ')[0]
            process = Popen('npm install -g ' + pkg, stdout=PIPE, stderr=STDOUT, shell=True)
            process.wait()
            output.append(process.stdout.read().decode('utf8'))
        msg = "\n".join(output)
    else:
        msg = "\n".join(updates)

    module.exit_json(changed=True, result=msg)


from ansible.module_utils.basic import *

if __name__ == '__main__':
    main()
